#!/usr/bin/env python
# -*- coding: utf-8 -*-

# author: Pocholo
# date: 8/18/21

# Comments directed to http://gimpchat.com

# Installation:
# This script should be placed in the user plugin folder

# Copyright (C)

#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by   
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.

#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program.  If not, see <https://www.gnu.org/licenses/>.

from gimpfu import *
import os, sys,time 
import random
import math
import gettext
gettext.install("gimp20", gimp.locale_directory, unicode=True)
					
def pm_create_stars_and_planet(more_lessStars, planet, changeColor, planColor, icePole, icePoleop,
                                atmosphere, atmoThickness, planet_shadow_phases1, planet_shadow_phases2, planet_shadow_phases3, sunAngle):

    #Initiates the temporary state
    #Set gimp to default
    pdb.gimp_context_push()
    pdb.gimp_context_set_defaults()
	   
    #Create the sky 
    img = pdb.gimp_image_new(1920, 1080, RGB)
    farLayer = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Stars", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_add_layer(img, farLayer, 0)
    pdb.gimp_context_set_foreground((000, 000, 000))
    pdb.gimp_drawable_fill(farLayer, FILL_FOREGROUND)
    pdb.plug_in_hsv_noise(img, farLayer, more_lessStars, 0, 0, 255)
    pdb.gimp_brightness_contrast(farLayer, -80, 50)
    pdb.plug_in_gauss(img, farLayer, 0.50, 0.50, 1)
    pdb.plug_in_sparkle(img, farLayer, 0.001, 1.00, 8, 4, 15, 1.00, 0, 0, 0, FALSE, FALSE, FALSE, 0)
         
    #Process
    pdb.gimp_display_new(img)
    
    #Create the near stars
    non_empty = pdb.gimp_edit_copy(farLayer)
    nearLayer = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Near stars", 100, LAYER_MODE_SCREEN)
    pdb.gimp_image_add_layer(img, nearLayer, 0)
    pdb.gimp_drawable_fill(nearLayer, FILL_TRANSPARENT)
    floating_sel = pdb.gimp_edit_paste(nearLayer, FALSE)
    pdb.gimp_floating_sel_anchor(floating_sel)
    pdb.gimp_layer_scale(nearLayer, 3000, 1688, FALSE)
    pdb.gimp_layer_resize_to_image_size(nearLayer)
    nearLayer = pdb.gimp_image_merge_down(img, nearLayer, CLIP_TO_IMAGE)

    #Create the nearest stars
    non_empty = pdb.gimp_edit_copy(nearLayer)
    nearestLayer = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Nearest stars", 100, LAYER_MODE_SCREEN)
    pdb.gimp_image_add_layer(img, nearestLayer, 0)
    pdb.gimp_drawable_fill(nearestLayer, FILL_TRANSPARENT)
    floating_sel = pdb.gimp_edit_paste(nearestLayer, FALSE)
    pdb.gimp_floating_sel_anchor(floating_sel)
    pdb.gimp_layer_scale(nearestLayer, 4000, 2250, FALSE)
    pdb.gimp_layer_resize_to_image_size(nearestLayer)
    starsLayer = pdb.gimp_image_merge_down(img, nearestLayer, CLIP_TO_IMAGE)
    pdb.gimp_image_set_active_layer(img, starsLayer)
    pdb.gimp_item_set_name(starsLayer, "Stars")
            
    #Create planet from gimp sources
    imgSize = 800
    centerX = 560 
    centerY = 140
    imgscale = img.width, img.height *2
    #Sunlight angle
    sunAngle = sunAngle/180.0 * math.pi
    
    if planet:
        planetLayer = pdb.gimp_layer_new(img, imgSize, imgSize, RGBA_IMAGE, "Planet", 100, LAYER_MODE_NORMAL)
        pdb.gimp_layer_add_alpha(planetLayer)
        pdb.gimp_image_add_layer(img, planetLayer, 0)       
        pdb.gimp_image_set_active_layer(img, planetLayer)
        pdb.gimp_layer_set_offsets(planetLayer, centerX, centerY)     #Center the image to the background
        
        #Planet terrain
        #pdb.plug_in_plasma(img, planetLayer, int(time.time()), 5)
        pdb.plug_in_solid_noise(img, planetLayer, FALSE, FALSE, int(time.time()), 15, 3, 3)
        pdb.gimp_drawable_desaturate(planetLayer, DESATURATE_LUMINANCE)
        pdb.gimp_levels(planetLayer, HISTOGRAM_RED, 255, 255, 1.00, 0, 255)
        pdb.gimp_drawable_hue_saturation(planetLayer, ALL_HUES, -14, 20, -20, 0)
           
        #Shadow color balance
        pdb.gimp_color_balance(planetLayer, 
                                             0,   #transfer_mode - shadows
                                          TRUE,   #preserve_lum
                                          -100,   #cyan_red
                                           100,   #magenta_green,
                                          -100)   #yellow_blue
        #Midtones color balance
        pdb.gimp_color_balance(planetLayer, 
                                             1,   #transfer_mode - midtones
                                          TRUE,   #preserve_lum
                                          -100,   #cyan_red
                                          -100,   #magenta_green,
                                           100)   #yellow_blue                                 
        #Hightlights color balance
        pdb.gimp_color_balance(planetLayer, 
                                             2,   #transfer_mode - hightlight
                                         FALSE,   #preserve_lum
                                          -100,   #cyan_red
                                          -100,   #magenta_green,
                                           100)   #yellow_blue      
                
        #Hightlights color balance
        pdb.gimp_color_balance(planetLayer, 
                                             2,   #transfer_mode - hightlight
                                         FALSE,   #preserve_lum
                                            50,   #cyan_red
                                             -10,   #magenta_green,
                                            20)   #yellow_blue   
                       
        #Convert the square to a circle
        pdb.plug_in_emboss(img, planetLayer, 90, 100, 7, FALSE)
        pdb.plug_in_applylens(img, planetLayer, 1.8, FALSE, FALSE, TRUE)
        pdb.gimp_layer_resize_to_image_size(planetLayer)
                
        #Make planet brighter
        non_empty = pdb.gimp_edit_copy(planetLayer)
        copyLayer = pdb.gimp_layer_new(img, imgSize, imgSize, RGBA_IMAGE, "Planet copy", 100, LAYER_MODE_SCREEN)
        pdb.gimp_image_add_layer(img, copyLayer, 0)
        pdb.gimp_layer_add_alpha(copyLayer)
        pdb.gimp_layer_set_offsets(copyLayer, centerX, centerY)
        pdb.gimp_layer_resize_to_image_size(copyLayer)
        pdb.gimp_drawable_fill(copyLayer, FILL_TRANSPARENT)
        copyLayer = pdb.gimp_edit_paste(copyLayer, FALSE)
        pdb.gimp_floating_sel_anchor(copyLayer)
        copyLayer = pdb.gimp_image_get_layer_by_name(img, "Planet copy")
        copyLayer = pdb.gimp_image_merge_down(img, copyLayer, CLIP_TO_IMAGE)
        planetLayer = pdb.gimp_image_get_layer_by_name(img, "Planet")
        pdb.gimp_drawable_hue_saturation(planetLayer, ALL_HUES, -7, 0, 0, 0)
            
    #Planet color
    if changeColor:
        planetColor = pdb.gimp_layer_new(img, imgSize, imgSize, RGBA_IMAGE, "Planet Color", 100, LAYER_MODE_LCH_HUE)
        pdb.gimp_image_add_layer(img, planetColor, 0)
        pdb.gimp_layer_add_alpha(planetColor)
        pdb.gimp_layer_set_offsets(planetColor, centerX, centerY)
        pdb.gimp_layer_resize_to_image_size(planetColor)
        pdb.gimp_context_set_foreground(planColor)
        pdb.gimp_image_select_item(img, 2, planetLayer)
        pdb.gimp_edit_bucket_fill(planetColor, BUCKET_FILL_FG, LAYER_MODE_NORMAL, 100, 255, FALSE, 0, 0)
        planetColor = pdb.gimp_image_merge_down(img, planetColor, CLIP_TO_IMAGE)
        planetLayer = pdb.gimp_image_get_layer_by_name(img, "Planet")
        colorbrightness = pdb.gimp_layer_new(img, imgSize, imgSize, RGBA_IMAGE, "Color Brightness", 50, LAYER_MODE_ADDITION )
        pdb.gimp_image_add_layer(img, colorbrightness, 0)
        pdb.gimp_layer_add_alpha(colorbrightness)
        pdb.gimp_layer_set_offsets(colorbrightness, centerX, centerY)
        pdb.gimp_layer_resize_to_image_size(colorbrightness)
        pdb.gimp_drawable_fill(colorbrightness, FILL_TRANSPARENT)
        pdb.gimp_edit_bucket_fill(colorbrightness, BUCKET_FILL_FG, LAYER_MODE_NORMAL, 100, 255, FALSE, 0, 0)
        colorbrightness = pdb.gimp_image_merge_down(img, colorbrightness, CLIP_TO_IMAGE)
        planetLayer = pdb.gimp_image_get_layer_by_name(img, "Planet")
                
    #Planet ice poles
    if icePole:    
        iceLayer = pdb.gimp_layer_new(img, imgSize, imgSize, RGBA_IMAGE, "Planet Ice Poles", icePoleop, LAYER_MODE_NORMAL)
        pdb.gimp_layer_add_alpha(iceLayer)
        pdb.gimp_image_add_layer(img, iceLayer, 0)
        pdb.gimp_drawable_fill(iceLayer, FILL_TRANSPARENT)
        pdb.gimp_layer_set_offsets(iceLayer, centerX, centerY)
        pdb.gimp_layer_resize_to_image_size(iceLayer)
        pdb.gimp_image_select_rectangle(img, 2, 860, 100, 200, 110)
        pdb.script_fu_distress_selection(img, iceLayer, 150, 4, 16, 1, FALSE, FALSE)
        pdb.gimp_context_set_foreground("White")
        pdb.gimp_drawable_edit_fill(iceLayer, FILL_FOREGROUND)
        pdb.gimp_image_select_rectangle(img, 2, 890, 850, 170, 120)
        pdb.script_fu_distress_selection(img, iceLayer, 150, 4, 16, 1, FALSE, FALSE)
        pdb.gimp_context_set_foreground("White")
        pdb.gimp_drawable_edit_fill(iceLayer, FILL_FOREGROUND)
        pdb.gimp_selection_none(img)  
        pdb.plug_in_gauss(img, iceLayer, 50, 50, 1)   #method=1
        pdb.plug_in_emboss(img, iceLayer, 90, 100, 10, FALSE)
        pdb.gimp_image_select_item(img, 2, planetLayer)
        pdb.gimp_selection_invert(img)
        pdb.gimp_edit_clear(iceLayer)
        pdb.gimp_selection_invert(img)
        iceLayer = pdb.gimp_image_merge_down(img, iceLayer, CLIP_TO_IMAGE)
        planetLayer = pdb.gimp_image_get_layer_by_name(img, "Planet")
        pdb.plug_in_autocrop_layer(img, planetLayer)
        pdb.gimp_selection_none(img)

    #Create the planet atmosphere
    if  atmosphere:   
        atmosphere = pdb.gimp_layer_new(img, imgSize, imgSize, RGBA_IMAGE, "Atmosphere", 100, LAYER_MODE_SCREEN)
        pdb.gimp_image_add_layer(img, atmosphere, 0)
        pdb.gimp_layer_add_alpha(atmosphere)
        pdb.gimp_layer_set_offsets(atmosphere, centerX, centerY)
        pdb.gimp_layer_resize_to_image_size(atmosphere)
        pdb.gimp_image_select_item(img, 2, planetLayer)
        pdb.gimp_context_set_foreground("white")
        pdb.gimp_selection_shrink(img, 4)
        pdb.gimp_selection_border(img, atmoThickness)
        pdb.gimp_edit_fill(atmosphere, FILL_WHITE)
        pdb.gimp_selection_none(img)       
        pdb.plug_in_gauss(img, atmosphere, 40, 40, 1)   #method=1
        non_empty = pdb.gimp_edit_copy(atmosphere)
        copyLayer2 = pdb.gimp_layer_new(img, imgSize, imgSize, RGBA_IMAGE, "Copy", 100, LAYER_MODE_ADDITION)
        pdb.gimp_image_add_layer(img, copyLayer2, 0)
        pdb.gimp_layer_add_alpha(copyLayer2)
        pdb.gimp_drawable_fill(copyLayer2, FILL_TRANSPARENT)
        floating_sel2 = pdb.gimp_edit_paste(copyLayer2, FALSE)
        pdb.gimp_floating_sel_anchor(floating_sel2)
        copyLayer2 = pdb.gimp_image_get_layer_by_name(img, "Copy")
        copyLayer2 = pdb.gimp_image_merge_down(img, copyLayer2, CLIP_TO_IMAGE)
        atmosphere = pdb.gimp_image_get_layer_by_name(img, "Atmosphere")
        pdb.gimp_image_select_item(img, 2, planetLayer)
        pdb.gimp_selection_invert(img)
        pdb.gimp_edit_clear(atmosphere)
        pdb.gimp_layer_set_mode(atmosphere, LAYER_MODE_SCREEN)
        pdb.gimp_layer_set_opacity(atmosphere, 100)
        pdb.gimp_selection_none(img)
        non_empty = pdb.gimp_edit_copy(atmosphere)
        lumLayer = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Planet Luminance", 100, LAYER_MODE_SCREEN)
        pdb.gimp_image_add_layer(img, lumLayer, 0)
        pdb.gimp_layer_add_alpha(lumLayer)
        pdb.gimp_drawable_fill(lumLayer, FILL_TRANSPARENT)
        lumLayer = pdb.gimp_edit_paste(lumLayer, FALSE)
        pdb.gimp_floating_sel_anchor(lumLayer)
        lumLayer = pdb.gimp_image_get_layer_by_name(img, "Planet Luminance")
        pdb.plug_in_gauss(img, lumLayer, 25, 25, 1)   #method=1
   
   #Create the planet shadow
    if planet_shadow_phases1:      
        crescent = pdb.gimp_layer_new(img, imgSize, imgSize, RGBA_IMAGE, "Crescent Shadow", 100, LAYER_MODE_NORMAL_LEGACY)
        pdb.gimp_image_add_layer(img, crescent, 0)
        pdb.gimp_layer_add_alpha(crescent)
        pdb.gimp_layer_set_offsets(crescent, centerX, centerY)
        pdb.gimp_layer_resize_to_image_size(crescent)
        pdb.gimp_context_set_foreground("Black")
        pdb.gimp_image_select_ellipse(img, CHANNEL_OP_REPLACE, 360, 250, 1200, 1000)
        pdb.gimp_edit_bucket_fill(crescent, BUCKET_FILL_FG, LAYER_MODE_NORMAL, 100, 255, FALSE, 0, 0)     
        pdb.gimp_selection_none(img)
        pdb.plug_in_gauss(img, crescent, 100, 100, 1)   #method=1
        pdb.gimp_layer_resize_to_image_size(crescent)
        pdb.gimp_image_set_active_layer(img, planetLayer)
        pdb.gimp_image_select_item(img, 2, planetLayer)
        pdb.gimp_selection_grow(img, 2)
        pdb.gimp_selection_invert(img)
        pdb.gimp_edit_clear(crescent)
        pdb.gimp_selection_none(img)
            
        #Crescent planet (glow)
        crescentGlow = pdb.gimp_layer_new(img, imgSize, imgSize, RGBA_IMAGE, "Crescent Glow", 100, LAYER_MODE_NORMAL_LEGACY)
        if  atmosphere:
            pdb.gimp_image_add_layer(img, crescentGlow, 4)  
        else:
            pdb.gimp_image_add_layer(img, crescentGlow, 2)         
        pdb.gimp_layer_add_alpha(crescentGlow)
        pdb.gimp_layer_set_offsets(crescentGlow, centerX, centerY)
        pdb.gimp_layer_resize_to_image_size(crescentGlow)
        pdb.gimp_image_set_active_layer(img, planetLayer)
        pdb.gimp_image_select_item(img, 2, planetLayer)
        pdb.gimp_context_set_foreground(planColor)
        pdb.gimp_edit_bucket_fill(crescentGlow, BUCKET_FILL_FG, LAYER_MODE_NORMAL, 100, 255, FALSE, 0, 0) 
        pdb.gimp_selection_none(img)
        crescentGlow = pdb.gimp_item_transform_translate(crescentGlow, 0, -200)
        pdb.gimp_layer_resize_to_image_size(crescentGlow)
        pdb.gimp_image_select_item(img, 2, planetLayer)     
        pdb.gimp_selection_invert(img)
        pdb.gimp_edit_clear(crescentGlow)
        pdb.gimp_selection_none(img)
        pdb.gimp_image_select_item(img, 2, crescentGlow)       
        pdb.gimp_selection_invert(img)
        pdb.gimp_edit_clear(crescentGlow)
        pdb.plug_in_gauss(img, crescentGlow, 40, 40, 1)   #method=1
        pdb.gimp_selection_none(img)
            
        #Crescent planet (light angle)
        crescentGlow = pdb.gimp_item_transform_rotate(crescentGlow, sunAngle, True, 0, 0)
        crescent = pdb.gimp_item_transform_rotate(crescent, sunAngle, True, 0, 0)
        pdb.gimp_layer_resize_to_image_size(crescent)
        pdb.gimp_layer_resize_to_image_size(crescentGlow)
        planetLayer = pdb.gimp_item_transform_rotate(planetLayer, sunAngle - 245, True, 0, 0)       
        planetLayer = pdb.gimp_item_transform_flip_simple(planetLayer, ORIENTATION_VERTICAL, TRUE, 0)
                        
    elif planet_shadow_phases2: 
        firstQuarter = pdb.gimp_layer_new(img, imgSize, imgSize, RGBA_IMAGE, "Quarter Shadow", 100, LAYER_MODE_NORMAL_LEGACY)
        pdb.gimp_image_add_layer(img, firstQuarter, 0)
        pdb.gimp_layer_add_alpha(firstQuarter)
        pdb.gimp_layer_set_offsets(firstQuarter, centerX, centerY)
        pdb.gimp_layer_resize_to_image_size(firstQuarter)
        pdb.gimp_context_set_foreground("Black")
        pdb.gimp_image_set_active_layer(img, planetLayer)
        pdb.gimp_image_select_item(img, 2, planetLayer)
        pdb.gimp_edit_bucket_fill(firstQuarter, BUCKET_FILL_FG, LAYER_MODE_NORMAL, 100, 255, FALSE, 0, 0)     
        pdb.gimp_image_select_rectangle(img, 2, 60, 0, 1920, 510)
        pdb.gimp_edit_clear(firstQuarter)
        pdb.gimp_selection_none(img)
        pdb.gimp_layer_scale(firstQuarter, 3000, 1688, TRUE)
        pdb.gimp_layer_resize_to_image_size(firstQuarter)
        pdb.plug_in_gauss(img, firstQuarter, 75, 75, 1)   #method=1
        pdb.gimp_image_set_active_layer(img, planetLayer)
        pdb.gimp_image_select_item(img, 2, planetLayer)
        pdb.gimp_selection_grow(img, 2)
        pdb.gimp_selection_invert(img)
        pdb.gimp_edit_clear(firstQuarter)
        pdb.gimp_selection_none(img)
            
        #First quarter planet (glow)
        quarterGlow = pdb.gimp_layer_new(img, imgSize, imgSize, RGBA_IMAGE, "First Quarter Glow", 100, LAYER_MODE_NORMAL_LEGACY)   
        if  atmosphere:
            pdb.gimp_image_add_layer(img, quarterGlow, 4)  
        else:
            pdb.gimp_image_add_layer(img, quarterGlow, 2)    
        pdb.gimp_layer_add_alpha(quarterGlow)
        pdb.gimp_layer_set_offsets(quarterGlow, centerX, centerY)
        pdb.gimp_layer_resize_to_image_size(quarterGlow)
        pdb.gimp_image_set_active_layer(img, planetLayer)
        pdb.gimp_image_select_item(img, 2, planetLayer)
        pdb.gimp_context_set_foreground(planColor)
        pdb.gimp_edit_bucket_fill(quarterGlow, BUCKET_FILL_FG, LAYER_MODE_NORMAL, 100, 255, FALSE, 0, 0) 
        pdb.gimp_selection_none(img)
        pdb.plug_in_gauss(img, quarterGlow, 20, 20, 1)   #method=1   
        pdb.gimp_image_select_item(img, 2, quarterGlow)       
        pdb.gimp_selection_grow(img, 50)
        pdb.gimp_selection_translate(img, 0, 150)
        pdb.gimp_edit_clear(quarterGlow)
        pdb.gimp_selection_none(img)
        pdb.plug_in_gauss(img, quarterGlow, 40, 40, 1)   #method=1
        pdb.gimp_image_select_item(img, 2, quarterGlow)
        pdb.gimp_selection_invert(img)
        pdb.gimp_edit_clear(quarterGlow)
        pdb.gimp_selection_none(img)
            
        #First quarter planet (light angle)
        firstQuarter = pdb.gimp_item_transform_rotate(firstQuarter, sunAngle, True, 0, 0)
        quarterGlow = pdb.gimp_item_transform_rotate(quarterGlow, sunAngle, True, 0, 0)
        pdb.gimp_layer_resize_to_image_size(firstQuarter)
        pdb.gimp_layer_resize_to_image_size(quarterGlow)
        planetLayer = pdb.gimp_item_transform_rotate(planetLayer, sunAngle - 245, True, 0, 0)       
        planetLayer = pdb.gimp_item_transform_flip_simple(planetLayer, ORIENTATION_VERTICAL, TRUE, 0)
                    
    elif planet_shadow_phases3: 
        waxingGibbous = pdb.gimp_layer_new(img, imgSize, imgSize, RGBA_IMAGE, "Waxing Gibbous Shadow", 100, LAYER_MODE_NORMAL_LEGACY)
        pdb.gimp_image_add_layer(img, waxingGibbous, 0)
        pdb.gimp_layer_add_alpha(waxingGibbous)
        pdb.gimp_layer_set_offsets(waxingGibbous, centerX, centerY)
        pdb.gimp_layer_resize_to_image_size(waxingGibbous)
        pdb.gimp_image_select_item(img, 2, planetLayer)
        pdb.gimp_context_set_foreground("Black")
        pdb.gimp_edit_bucket_fill(waxingGibbous, BUCKET_FILL_FG, LAYER_MODE_NORMAL, 100, 255, FALSE, 0, 0)     
        pdb.gimp_image_select_ellipse(img, CHANNEL_OP_REPLACE, 360, -400, 1200, 1000)
        pdb.gimp_edit_clear(waxingGibbous)
        pdb.gimp_selection_none(img)
        pdb.gimp_layer_scale(waxingGibbous, 2400, 2184, TRUE)
        pdb.gimp_layer_resize_to_image_size(waxingGibbous)        
        pdb.plug_in_gauss(img, waxingGibbous, 130, 130, 1)   #method=1
        pdb.gimp_image_set_active_layer(img, planetLayer)
        pdb.gimp_image_select_item(img, 2, planetLayer)
        pdb.gimp_selection_grow(img, 2)
        pdb.gimp_selection_invert(img)
        pdb.gimp_edit_clear(waxingGibbous)
        pdb.gimp_selection_none(img)
            
        #Waxing gibbous planet (glow)
        gibbousGlow = pdb.gimp_layer_new(img, imgSize, imgSize, RGBA_IMAGE, "Gibbous Glow", 100, LAYER_MODE_NORMAL_LEGACY)
        if  atmosphere:
            pdb.gimp_image_add_layer(img, gibbousGlow, 4)  
        else:
            pdb.gimp_image_add_layer(img, gibbousGlow, 2)                  
        pdb.gimp_layer_add_alpha(gibbousGlow)
        pdb.gimp_layer_set_offsets(gibbousGlow, centerX, centerY)
        pdb.gimp_layer_resize_to_image_size(gibbousGlow)
        pdb.gimp_image_set_active_layer(img, planetLayer)
        pdb.gimp_image_select_item(img, 2, planetLayer)
        pdb.gimp_context_set_foreground(planColor)
        pdb.gimp_edit_bucket_fill(gibbousGlow, BUCKET_FILL_FG, LAYER_MODE_NORMAL, 100, 255, FALSE, 0, 0) 
        pdb.gimp_selection_none(img)
        pdb.gimp_image_select_item(img, 2, waxingGibbous) 
        pdb.gimp_edit_clear(gibbousGlow)
        pdb.gimp_image_select_item(img, 2, planetLayer)       
        pdb.gimp_selection_invert(img)
        pdb.gimp_edit_clear(gibbousGlow)
        pdb.gimp_selection_none(img)        
        pdb.plug_in_gauss(img, gibbousGlow, 50, 50, 1)   #method=1
        pdb.gimp_image_select_item(img, 2, gibbousGlow)
        pdb.gimp_selection_invert(img)
        pdb.gimp_edit_clear(gibbousGlow)
        pdb.gimp_selection_none(img)
            
        #Waxing gibbous planet (light angle)
        waxingGibbous = pdb.gimp_item_transform_rotate(waxingGibbous, sunAngle, True, 0, 0)
        gibbousGlow = pdb.gimp_item_transform_rotate(gibbousGlow, sunAngle, True, 0, 0)
        pdb.gimp_layer_resize_to_image_size(waxingGibbous)
        pdb.gimp_layer_resize_to_image_size(gibbousGlow)
        planetLayer = pdb.gimp_item_transform_rotate(planetLayer, sunAngle - 245, True, 0, 0)       
        planetLayer = pdb.gimp_item_transform_flip_simple(planetLayer, ORIENTATION_VERTICAL, TRUE, 0)
       
    #Make active the bottom layer and done
    pdb.gimp_image_set_active_layer(img, starsLayer)
    
    #Set gimp to default
    #Set gimp to default
    pdb.gimp_context_pop()
   	
register(
    "pm_create_stars_and_planet",
    "Creates Stars and Planet",
    "Creates Stars and Planet",
    "Pocholo",
    "Pocholo",
    "2021",
    "Create Stars and a Planet",
    "",
    [    
    (PF_SLIDER, "more_lessStars", "← More Stars/Less Stars →", 6, (1, 8, 1)),
    (PF_BOOL, "planet", "Create Planet?" " "  
    "if no, then create Stars only", True),  
    (PF_BOOL, "changeColor", "Change the Planet Color?:", False),
    (PF_COLOR, "planColor", "Planet Color:", (94, 150, 255)),
    (PF_BOOL, "icePole", "Ice Poles?:", True),
    (PF_SLIDER, "icePoleop", "Ice Pole Opacity ← Reduce/Increase →", 75, (0, 75, 1)),
    (PF_BOOL, "atmosphere", "Planet Atmosphere?:", True),
    (PF_SLIDER, "atmoThickness", "Atmosphere thickness:", 4, (2, 4, 1)),
    (PF_BOOL, "planet_shadow_phase1", "Crescent Shadow", False), 
    (PF_BOOL, "planet_shadow_phase2", "Quarter Planet Shadow",  False),   
    (PF_BOOL, "planet_shadow_phase3", "Waxing Gibbous Shadow", False),   
    (PF_SPINNER, "sunAngle", "Sun Angle (degrees):", 45, (0, 180, 45)),
    ],
    [],
    pm_create_stars_and_planet, menu="<Image>/File/Create/Create Stars and a Planet",
    domain=("gimp20", gimp.locale_directory))
main()						   				